@@ -1,17 +1,21 @@
-/*
- *  Copyright 2001-2007 Internet2
- * 
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+/**
+ * Licensed to the University Corporation for Advanced Internet
+ * Development, Inc. (UCAID) under one or more contributor license
+ * agreements. See the NOTICE file distributed with this work for
+ * additional information regarding copyright ownership.
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ * UCAID licenses this file to you under the Apache License,
+ * Version 2.0 (the "License"); you may not use this file except
+ * in compliance with the License. You may obtain a copy of the
+ * License at
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
+ * either express or implied. See the License for the specific
+ * language governing permissions and limitations under the License.
  */
 
 /**
@@ -64,6 +68,13 @@ namespace opensaml {
          */
         virtual bool isUserAgentPresent() const;
 
+        /**
+         * Returns identifier for the protocol family associated with the encoder.
+         *
+         * @return  a protocol family identifier, or nullptr
+         */
+        virtual const XMLCh* getProtocolFamily() const;
+
         /**
          * Interface to caller-supplied artifact generation mechanism.
          * 
@@ -124,12 +135,12 @@ namespace opensaml {
             xmltooling::GenericResponse& genericResponse,
             xmltooling::XMLObject* xmlObject,
             const char* destination,
-            const saml2md::EntityDescriptor* recipient=NULL,
-            const char* relayState=NULL,
-            const ArtifactGenerator* artifactGenerator=NULL,
-            const xmltooling::Credential* credential=NULL,
-            const XMLCh* signatureAlg=NULL,
-            const XMLCh* digestAlg=NULL
+            const saml2md::EntityDescriptor* recipient=nullptr,
+            const char* relayState=nullptr,
+            const ArtifactGenerator* artifactGenerator=nullptr,
+            const xmltooling::Credential* credential=nullptr,
+            const XMLCh* signatureAlg=nullptr,
+            const XMLCh* digestAlg=nullptr
             ) const=0;
 
     protected:
