@@ -1,17 +1,21 @@
-/*
- *  Copyright 2001-2007 Internet2
- * 
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+/**
+ * Licensed to the University Corporation for Advanced Internet
+ * Development, Inc. (UCAID) under one or more contributor license
+ * agreements. See the NOTICE file distributed with this work for
+ * additional information regarding copyright ownership.
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ * UCAID licenses this file to you under the Apache License,
+ * Version 2.0 (the "License"); you may not use this file except
+ * in compliance with the License. You may obtain a copy of the
+ * License at
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
+ * either express or implied. See the License for the specific
+ * language governing permissions and limitations under the License.
  */
 
 /*
@@ -80,13 +84,18 @@ using namespace xercesc;
 
 #define SAML_LOGCAT "OpenSAML"
 
+namespace xmltooling {
+    class XMLTOOL_API Mutex;
+};
+
 namespace opensaml {
     
     /// @cond OFF
-    class SAMLInternalConfig : public SAMLConfig
+    class SAML_DLLLOCAL SAMLInternalConfig : public SAMLConfig
     {
     public:
-        SAMLInternalConfig() {}
+        SAMLInternalConfig();
+        ~SAMLInternalConfig();
 
         static SAMLInternalConfig& getInternalConfig();
 
@@ -98,7 +107,10 @@ namespace opensaml {
         void generateRandomBytes(std::string& buf, unsigned int len);
         XMLCh* generateIdentifier();
         std::string hashSHA1(const char* data, bool toHex=false);
+
     private:
+        int m_initCount;
+        xmltooling::Mutex* m_lock;
     };
     /// @endcond
 
