@@ -1,17 +1,21 @@
-/*
- *  Copyright 2001-2009 Internet2
- * 
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+/**
+ * Licensed to the University Corporation for Advanced Internet
+ * Development, Inc. (UCAID) under one or more contributor license
+ * agreements. See the NOTICE file distributed with this work for
+ * additional information regarding copyright ownership.
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ * UCAID licenses this file to you under the Apache License,
+ * Version 2.0 (the "License"); you may not use this file except
+ * in compliance with the License. You may obtain a copy of the
+ * License at
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
+ * either express or implied. See the License for the specific
+ * language governing permissions and limitations under the License.
  */
 
 /**
@@ -42,7 +46,7 @@ using namespace xmltooling;
 using namespace std;
 
 SAML2SOAPClient::SAML2SOAPClient(opensaml::SOAPClient& soaper, bool fatalSAMLErrors)
-    : m_soaper(soaper), m_fatal(fatalSAMLErrors), m_correlate(NULL)
+    : m_soaper(soaper), m_fatal(fatalSAMLErrors), m_correlate(nullptr)
 {
 }
 
@@ -92,7 +96,7 @@ StatusResponseType* SAML2SOAPClient::receiveSAML()
                 // Check Status.
                 Status* status = response->getStatus();
                 if (status) {
-                    const XMLCh* code = status->getStatusCode() ? status->getStatusCode()->getValue() : NULL;
+                    const XMLCh* code = status->getStatusCode() ? status->getStatusCode()->getValue() : nullptr;
                     if (code && !XMLString::equals(code,StatusCode::SUCCESS) && handleError(*status)) {
                         BindingException ex("SAML response contained an error.");
                         annotateException(&ex, policy.getIssuerMetadata(), status);   // throws it
@@ -112,13 +116,13 @@ StatusResponseType* SAML2SOAPClient::receiveSAML()
         else
             ex.raise();
     }
-    return NULL;
+    return nullptr;
 }
 
 bool SAML2SOAPClient::handleError(const Status& status)
 {
-    auto_ptr_char code((status.getStatusCode() ? status.getStatusCode()->getValue() : NULL));
-    auto_ptr_char str((status.getStatusMessage() ? status.getStatusMessage()->getMessage() : NULL));
+    auto_ptr_char code((status.getStatusCode() ? status.getStatusCode()->getValue() : nullptr));
+    auto_ptr_char str((status.getStatusMessage() ? status.getStatusMessage()->getMessage() : nullptr));
     Category::getInstance(SAML_LOGCAT".SOAPClient").error(
         "SOAP client detected a SAML error: (%s) (%s)",
         (code.get() ? code.get() : "no code"),
