@@ -1,17 +1,21 @@
-/*
- *  Copyright 2001-2009 Internet2
- * 
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+/**
+ * Licensed to the University Corporation for Advanced Internet
+ * Development, Inc. (UCAID) under one or more contributor license
+ * agreements. See the NOTICE file distributed with this work for
+ * additional information regarding copyright ownership.
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ * UCAID licenses this file to you under the Apache License,
+ * Version 2.0 (the "License"); you may not use this file except
+ * in compliance with the License. You may obtain a copy of the
+ * License at
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
+ * either express or implied. See the License for the specific
+ * language governing permissions and limitations under the License.
  */
 
 #ifdef WIN32
@@ -106,7 +110,7 @@ protected:
     }
 
     void assertEquals(const char* failMessage, const XMLCh* expectedString, const XMLCh* testString) {
-        char* buf = NULL;
+        char* buf = nullptr;
         if (!XMLString::equals(expectedString, testString)) {
             buf = XMLString::transcode(testString);
             TS_TRACE(buf ? buf : "(NULL)");
@@ -147,7 +151,7 @@ public:
 class SAMLObjectValidatorBaseTestCase : virtual public SAMLObjectBaseTestCase {
 
     public:
-        SAMLObjectValidatorBaseTestCase() : target(NULL), targetQName(NULL), builder(NULL), validator(NULL) {}
+        SAMLObjectValidatorBaseTestCase() : target(nullptr), targetQName(nullptr), builder(nullptr), validator(nullptr) {}
 
         virtual ~SAMLObjectValidatorBaseTestCase() {
             delete validator;
@@ -230,9 +234,9 @@ class SAMLObjectValidatorBaseTestCase : virtual public SAMLObjectBaseTestCase {
          */
         XMLObject* buildXMLObject(xmltooling::QName &targetQName) {
             // Create the builder on the first request only, for efficiency
-            if (builder == NULL) {
+            if (builder == nullptr) {
                 builder = XMLObjectBuilder::getBuilder(targetQName);
-                TSM_ASSERT("Unable to retrieve builder for object QName: " + targetQName.toString(), builder!=NULL);
+                TSM_ASSERT("Unable to retrieve builder for object QName: " + targetQName.toString(), builder!=nullptr);
             }
             return builder->buildObject(targetQName.getNamespaceURI(), targetQName.getLocalPart(), targetQName.getPrefix());
 
@@ -245,16 +249,16 @@ class SAMLObjectValidatorBaseTestCase : virtual public SAMLObjectBaseTestCase {
 
             TSM_ASSERT("targetQName was empty", targetQName.hasLocalPart());
 
-            TSM_ASSERT("validator was null", validator!=NULL);
+            TSM_ASSERT("validator was null", validator!=nullptr);
 
             target = buildXMLObject(targetQName);
-            TSM_ASSERT("XMLObject target was NULL", target!=NULL);
+            TSM_ASSERT("XMLObject target was NULL", target!=nullptr);
             populateRequiredData();
         }
 
         void tearDown() {
             delete target;
-            target=NULL;
+            target=nullptr;
             SAMLObjectBaseTestCase::tearDown();
         }
 
