@@ -1,17 +1,21 @@
-/*
- *  Copyright 2001-2007 Internet2
- * 
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+/**
+ * Licensed to the University Corporation for Advanced Internet
+ * Development, Inc. (UCAID) under one or more contributor license
+ * agreements. See the NOTICE file distributed with this work for
+ * additional information regarding copyright ownership.
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ * UCAID licenses this file to you under the Apache License,
+ * Version 2.0 (the "License"); you may not use this file except
+ * in compliance with the License. You may obtain a copy of the
+ * License at
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
+ * either express or implied. See the License for the specific
+ * language governing permissions and limitations under the License.
  */
 
 #include "binding.h"
@@ -51,11 +55,11 @@ public:
             cc.setUsage(Credential::SIGNING_CREDENTIAL);
             Locker clocker(m_creds);
             const Credential* cred = m_creds->resolve(&cc);
-            TSM_ASSERT("Retrieved credential was null", cred!=NULL);
+            TSM_ASSERT("Retrieved credential was null", cred!=nullptr);
 
             // Freshen timestamp and ID.
-            toSend->setIssueInstant(time(NULL));
-            toSend->setID(NULL);
+            toSend->setIssueInstant(time(nullptr));
+            toSend->setID(nullptr);
     
             // Encode message.
             auto_ptr_XMLCh lit1("MessageEncoder");
@@ -64,11 +68,11 @@ public:
             auto_ptr_XMLCh lit3(path.c_str());
             DOMDocument* encoder_config = XMLToolingConfig::getConfig().getParser().newDocument();
             XercesJanitor<DOMDocument> janitor2(encoder_config);
-            encoder_config->appendChild(encoder_config->createElementNS(NULL,lit1.get()));
-            encoder_config->getDocumentElement()->setAttributeNS(NULL,lit2.get(),lit3.get());
+            encoder_config->appendChild(encoder_config->createElementNS(nullptr,lit1.get()));
+            encoder_config->getDocumentElement()->setAttributeNS(nullptr,lit2.get(),lit3.get());
             auto_ptr<MessageEncoder> encoder(
                 SAMLConfig::getConfig().MessageEncoderManager.newPlugin(
-                    samlconstants::SAML20_BINDING_HTTP_POST, pair<const DOMElement*,const XMLCh*>(encoder_config->getDocumentElement(), NULL)
+                    samlconstants::SAML20_BINDING_HTTP_POST, pair<const DOMElement*,const XMLCh*>(encoder_config->getDocumentElement(), nullptr)
                     )
                 );
             Locker locker(m_metadata);
@@ -78,7 +82,7 @@ public:
                 "https://sp.example.org/SAML/SSO",
                 m_metadata->getEntityDescriptor(MetadataProvider::Criteria("https://sp.example.org/")).first,
                 "state",
-                NULL,
+                nullptr,
                 cred
                 );
             toSend.release();
@@ -87,7 +91,7 @@ public:
             string relayState;
             auto_ptr<MessageDecoder> decoder(
                 SAMLConfig::getConfig().MessageDecoderManager.newPlugin(
-                    samlconstants::SAML20_BINDING_HTTP_POST, pair<const DOMElement*,const XMLCh*>(NULL,NULL)
+                    samlconstants::SAML20_BINDING_HTTP_POST, pair<const DOMElement*,const XMLCh*>(nullptr,nullptr)
                     )
                 );
             auto_ptr<Response> response(dynamic_cast<Response*>(decoder->decode(relayState,*this,policy)));
@@ -130,11 +134,11 @@ public:
             cc.setUsage(Credential::SIGNING_CREDENTIAL);
             Locker clocker(m_creds);
             const Credential* cred = m_creds->resolve(&cc);
-            TSM_ASSERT("Retrieved credential was null", cred!=NULL);
+            TSM_ASSERT("Retrieved credential was null", cred!=nullptr);
 
             // Freshen timestamp and ID.
-            toSend->setIssueInstant(time(NULL));
-            toSend->setID(NULL);
+            toSend->setIssueInstant(time(nullptr));
+            toSend->setID(nullptr);
     
             // Encode message.
             auto_ptr_XMLCh lit1("MessageEncoder");
@@ -143,11 +147,11 @@ public:
             auto_ptr_XMLCh lit3(path.c_str());
             DOMDocument* encoder_config = XMLToolingConfig::getConfig().getParser().newDocument();
             XercesJanitor<DOMDocument> janitor2(encoder_config);
-            encoder_config->appendChild(encoder_config->createElementNS(NULL,lit1.get()));
-            encoder_config->getDocumentElement()->setAttributeNS(NULL,lit2.get(),lit3.get());
+            encoder_config->appendChild(encoder_config->createElementNS(nullptr,lit1.get()));
+            encoder_config->getDocumentElement()->setAttributeNS(nullptr,lit2.get(),lit3.get());
             auto_ptr<MessageEncoder> encoder(
                 SAMLConfig::getConfig().MessageEncoderManager.newPlugin(
-                    samlconstants::SAML20_BINDING_HTTP_POST_SIMPLESIGN, pair<const DOMElement*,const XMLCh*>(encoder_config->getDocumentElement(),NULL)
+                    samlconstants::SAML20_BINDING_HTTP_POST_SIMPLESIGN, pair<const DOMElement*,const XMLCh*>(encoder_config->getDocumentElement(),nullptr)
                     )
                 );
             Locker locker(m_metadata);
@@ -157,7 +161,7 @@ public:
                 "https://sp.example.org/SAML/SSO",
                 m_metadata->getEntityDescriptor(MetadataProvider::Criteria("https://sp.example.org/")).first,
                 "state",
-                NULL,
+                nullptr,
                 cred
                 );
             toSend.release();
@@ -166,7 +170,7 @@ public:
             string relayState;
             auto_ptr<MessageDecoder> decoder(
                 SAMLConfig::getConfig().MessageDecoderManager.newPlugin(
-                    samlconstants::SAML20_BINDING_HTTP_POST_SIMPLESIGN, pair<const DOMElement*,const XMLCh*>(NULL,NULL)
+                    samlconstants::SAML20_BINDING_HTTP_POST_SIMPLESIGN, pair<const DOMElement*,const XMLCh*>(nullptr,nullptr)
                     )
                 );
             auto_ptr<Response> response(dynamic_cast<Response*>(decoder->decode(relayState,*this,policy)));
